//---------------------------------------------------------------------------

#include <vcl.h>
#pragma hdrstop

#include "FormButtonEdit.h"
#include "ButtonType.h"
#include "ButtonConf.h"
#include "Colors.h"
//---------------------------------------------------------------------------
#pragma package(smart_init)
#pragma resource "*.dfm"
TfrmButtonEdit *frmButtonEdit;
//---------------------------------------------------------------------------
__fastcall TfrmButtonEdit::TfrmButtonEdit(TComponent* Owner)
	: TForm(Owner)
{
    pageControl->ActivePage = tsVisual;
	for (int i=0; i<Button::TYPE_LIMITER; i++)
	{
		cbType->Items->Add(Button::TypeName((Button::Type)i));
	}
	cbBackgroundColor->Items->Clear();
	for (int i=0; i<Color::clLimiter; i++)
	{
        cbBackgroundColor->Items->Add(Color::IdToText(static_cast<Color::Id>(i)));
	}
	colorDialog->Color = clGray;
}
//---------------------------------------------------------------------------
void __fastcall TfrmButtonEdit::FormShow(TObject *Sender)
{
	confirmed = false;	
}
//---------------------------------------------------------------------------

void __fastcall TfrmButtonEdit::ShowModal(ButtonConf *cfg)
{
	this->cfg = cfg;
	ApplyConf();
	TForm::ShowModal();
}

void TfrmButtonEdit::ApplyConf(void)
{
	cbType->ItemIndex = cfg->type;
	edDescription->Text = cfg->caption.c_str();
	edNumber->Text = cfg->number.c_str();
	chbNoIcon->Checked = cfg->noIcon;
	edHeight->Text = cfg->height;
	edMarginTop->Text = cfg->marginTop;
	edMarginBottom->Text = cfg->marginBottom;
	int colorId = Color::IntTColorToId(cfg->backgroundColor);
	cbBackgroundColor->ItemIndex = colorId;
	if (colorId != Color::clCustom)
	{
		btnSelectBackgroundColor->Visible = false;
	}
	else
	{
		btnSelectBackgroundColor->Visible = true;
    }

	edImgIdle->Text = cfg->imgIdle.c_str();
	edImgConfirmed->Text = cfg->imgConfirmed.c_str();
	edImgTerminated->Text = cfg->imgTerminated.c_str();
	edImgEarly->Text = cfg->imgEarly.c_str();

	chbBlfOverrideIdle->Checked = cfg->blfOverrideIdle.active;
	edBlfOverrideIdle->Text = cfg->blfOverrideIdle.number.c_str();
	chbBlfOverrideTerminated->Checked = cfg->blfOverrideTerminated.active;
	edBlfOverrideTerminated->Text = cfg->blfOverrideTerminated.number.c_str();
	chbBlfOverrideEarly->Checked = cfg->blfOverrideEarly.active;
	edBlfOverrideEarly->Text = cfg->blfOverrideEarly.number.c_str();
	chbBlfOverrideConfirmed->Checked = cfg->blfOverrideConfirmed.active;
	edBlfOverrideConfirmed->Text = cfg->blfOverrideConfirmed.number.c_str();

	cbBlfActionDuringCall->ItemIndex = cfg->blfActionDuringCall;
	edBlfDtmfPrefixDuringCall->Text = cfg->blfDtmfPrefixDuringCall.c_str();

	edArg1->Text = cfg->arg1.c_str();

	edPagingTxWaveFile->Text = cfg->pagingTxWaveFile.c_str();

	SetType(cfg->type);
}

void __fastcall TfrmButtonEdit::btnApplyClick(TObject *Sender)
{
	confirmed = true;
	cfg->type = static_cast<Button::Type>(cbType->ItemIndex);
	cfg->caption = edDescription->Text.c_str();
	cfg->number = edNumber->Text.c_str();
	cfg->noIcon = chbNoIcon->Checked;
	cfg->height = StrToIntDef(edHeight->Text, 32);
	cfg->marginTop = StrToIntDef(edMarginTop->Text, 0);
	if (cfg->marginTop > 200)
		cfg->marginTop = 0;
	cfg->marginBottom = StrToIntDef(edMarginBottom->Text, 0);
	if (cfg->marginBottom > 200)
		cfg->marginBottom = 0;
	if (cbBackgroundColor->ItemIndex != Color::clCustom)
	{
		cfg->backgroundColor = Color::IdToIntTColor(static_cast<Color::Id>(cbBackgroundColor->ItemIndex));
	}
	else
	{
        cfg->backgroundColor = colorDialog->Color;
	}

	cfg->imgIdle = edImgIdle->Text.c_str();
	cfg->imgConfirmed = edImgConfirmed->Text.c_str();
	cfg->imgTerminated = edImgTerminated->Text.c_str();
	cfg->imgEarly = edImgEarly->Text.c_str();

	cfg->blfOverrideIdle.active = chbBlfOverrideIdle->Checked;
	cfg->blfOverrideIdle.number = edBlfOverrideIdle->Text.c_str();
	cfg->blfOverrideTerminated.active = chbBlfOverrideTerminated->Checked;
	cfg->blfOverrideTerminated.number = edBlfOverrideTerminated->Text.c_str();
	cfg->blfOverrideEarly.active = chbBlfOverrideEarly->Checked;
	cfg->blfOverrideEarly.number = edBlfOverrideEarly->Text.c_str();
	cfg->blfOverrideConfirmed.active = chbBlfOverrideConfirmed->Checked;
	cfg->blfOverrideConfirmed.number = edBlfOverrideConfirmed->Text.c_str();

	cfg->blfActionDuringCall = static_cast<ButtonConf::BlfActionDuringCall>(cbBlfActionDuringCall->ItemIndex);
	cfg->blfDtmfPrefixDuringCall = edBlfDtmfPrefixDuringCall->Text.c_str();

	cfg->arg1 = edArg1->Text.c_str();

	cfg->pagingTxWaveFile = edPagingTxWaveFile->Text.c_str();

	Close();
}
//---------------------------------------------------------------------------

void __fastcall TfrmButtonEdit::btnCancelClick(TObject *Sender)
{
	Close();
}
//---------------------------------------------------------------------------

void __fastcall TfrmButtonEdit::cbTypeChange(TObject *Sender)
{
	SetType(static_cast<Button::Type>(cbType->ItemIndex));	
}
//---------------------------------------------------------------------------

void TfrmButtonEdit::SetType(Button::Type type)
{
	memoHelp->Text = Button::TypeDescription(type);

	edNumber->Visible = true;
	lblNumber->Visible = true;
	chbNoIcon->Enabled = true;

	lblArg1->Visible = false;
	edArg1->Visible = false;

	lblPagingTxWaveFile->Visible = false;
	edPagingTxWaveFile->Visible = false;

	switch (type)
	{
	case Button::DISABLED:
		edNumber->Visible = false;
		lblNumber->Visible = false;
		break;
	case Button::BLF:
		chbNoIcon->Checked = false;
		chbNoIcon->Enabled = false;
		break;
	case Button::REDIAL:
		edNumber->Visible = false;
		lblNumber->Visible = false;
		break;
	case Button::TRANSFER:
	case Button::HOLD:
	case Button::HTTP_QUERY:
		edNumber->Visible = false;
		lblNumber->Visible = false;
		break;
	case Button::EXECUTE:
		lblArg1->Visible = true;
		edArg1->Visible = true;
		break;
	case Button::PAGING_TX:
		lblPagingTxWaveFile->Visible = true;
		edPagingTxWaveFile->Visible = true;
		break;
	default:
		break;
	}
}

void __fastcall TfrmButtonEdit::SelectImgClick(TObject *Sender)
{
	TEdit *edit = NULL;
	TButton *btn = dynamic_cast<TButton*>(Sender);
	if (btn == btnSelectImgIdle)
		edit = edImgIdle;
	else if (btn == btnSelectImgTerminated)
		edit = edImgTerminated;
	else if (btn == btnSelectImgEarly)
		edit = edImgEarly;
	else if (btn == btnSelectImgConfirmed)
		edit = edImgConfirmed;

	if (!edit)
		return;
	AnsiString dir = ExtractFileDir(Application->ExeName) + "\\img\\";
	openDialog->InitialDir = dir;
	if (FileExists(dir + edit->Text))
		openDialog->FileName = dir + edit->Text;
	if (openDialog->Execute())
	{
    	edit->Text = ExtractFileName(openDialog->FileName);
	}
}
//---------------------------------------------------------------------------

void __fastcall TfrmButtonEdit::btnClearClick(TObject *Sender)
{
	cfg->Reset();
	ApplyConf();
}
//---------------------------------------------------------------------------

void __fastcall TfrmButtonEdit::SelectColorClick(TObject *Sender)
{
	colorDialog->Color = static_cast<TColor>(cfg->backgroundColor);
	colorDialog->Execute();
}
//---------------------------------------------------------------------------

void __fastcall TfrmButtonEdit::cbBackgroundColorChange(TObject *Sender)
{
	if (cbBackgroundColor->ItemIndex == Color::clCustom)
	{
		btnSelectBackgroundColor->Visible = true;
	}
	else
	{
        btnSelectBackgroundColor->Visible = false;
    }
}
//---------------------------------------------------------------------------

